@@ -1,7 +1,7 @@
 package Complete::Module;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,6 +22,7 @@ if ($ENV{COMPLETE_MODULE_OPT_SHORTCUT_PREFIXES}) {
         { split /=|;/, $ENV{COMPLETE_MODULE_OPT_SHORTCUT_PREFIXES} };
 } else {
     $OPT_SHORTCUT_PREFIXES = {
+        df  => 'DateTime/Format/',
         dzb => 'Dist/Zilla/PluginBundle/',
         dzp => 'Dist/Zilla/Plugin/',
         dzr => 'Dist/Zilla/Role/',
@@ -231,7 +232,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.20 of Complete::Module (from Perl distribution Complete-Module), released on 2015-09-17.
+This document describes version 0.21 of Complete::Module (from Perl distribution Complete-Module), released on 2015-09-23.
 
 =head1 SYNOPSIS
 
@@ -246,6 +247,7 @@ This document describes version 0.20 of Complete::Module (from Perl distribution
 Shortcut prefixes. The default is:
 
  {
+   df  => "DateTime/Format/",
    dzb => "Dist/Zilla/PluginBundle/",
    dzp => "Dist/Zilla/Plugin/",
    dzr => "Dist/Zilla/Role/",
